@@ -3,7 +3,7 @@
 # This script is part of khmer, http://github.com/ged-lab/khmer/, and is
 # Copyright (C) Michigan State University, 2009-2013. It is licensed under
 # the three-clause BSD license; see doc/LICENSE.txt. Contact: ctb@msu.edu
-# 
+#
 """
 Take a file containing a mixture of interleaved and orphaned reads, and
 extract them into separate files (.pe and .se).
@@ -17,6 +17,7 @@ import sys
 import os.path
 import argparse
 
+
 def is_pair(name1, name2):
     if name1.endswith('/1') and name2.endswith('/2'):
         s1 = name1.split('/')[0]
@@ -27,13 +28,16 @@ def is_pair(name1, name2):
 
     return False
 
+
 def output_pair(r1, r2):
     if hasattr(r1, 'accuracy'):
         return "@%s\n%s\n+\n%s\n@%s\n%s\n+\n%s\n" % \
             (r1.name, r1.sequence, r1.accuracy,
              r2.name, r2.sequence, r2.accuracy)
     else:
-        return ">%s\n%s\n>%s\n%s\n" % (r1.name, r1.sequence, r2.name, r2.sequence)
+        return ">%s\n%s\n>%s\n%s\n" % (r1.name, r1.sequence, r2.name,
+                                       r2.sequence)
+
 
 def output_single(r):
     if hasattr(r, 'accuracy'):
@@ -41,9 +45,11 @@ def output_single(r):
     else:
         return ">%s\n%s\n" % (r.name, r.sequence)
 
+
 def main():
-    parser = argparse.ArgumentParser(\
-       description='Take a mixture of reads and split into pairs and orphans.')
+    parser = argparse.ArgumentParser(
+        description=
+        'Take a mixture of reads and split into pairs and orphans.')
 
     parser.add_argument('infile')
     args = parser.parse_args()
@@ -70,7 +76,6 @@ def main():
         if n % 100000 == 0 and n > 0:
             print '...', n
         name = record['name'].split()[0]
-        sequence = record['sequence']
 
         if last_record:
             if is_pair(last_name, name):
